Image View
==========

The Image View is a container for an image to be rendered on the display

Usage
-----

.. code-block:: Python

    import toga
    
    view = toga.ImageView(id='view1', image=my_image)

Supported Platforms
-------------------

.. include:: ../supported_platforms/ImageView.rst

Reference
---------

.. autoclass:: toga.interface.widgets.imageview.ImageView
   :members:
   :undoc-members:
   :inherited-members: